library(survey)
library(dplyr)

## Figure 1
# Proportion ayant une date mise en couple<date de fin d’étude et
# s’étant rencontrés dans le cadre des études selon la cohorte
opar <- par(no.readonly = TRUE)
layout(matrix(c(1, 2, 3, 4), 2, 2, byrow=TRUE), heights=c(8, 1))
bw <- 4

#premières relations
plot(NULL, main="Premières relations", yaxt="n",
     xlim=c(1948, 1988), xaxs="i", ylim=c(0, .8), lwd=0,
     ylab="Proportion des rencontres (en %)",
     xlab="Année de naissance")
axis(2, seq(0, 1, by=.1), seq(0, 100,  by=10))
abline(h=seq(0, 1, by=.1), col="light grey", lty="dotted")
lines(svysmooth(temps_etude ~ ANAISR, bandwidth=bw,
                subset(svyhist, H_NREL_CORR == 1 & SEXER == "H")),
      lty=2)
lines(svysmooth(temps_etude ~ ANAISR, bandwidth=bw,
                subset(svyhist, H_NREL_CORR == 1 & SEXER == "F")),
      lty=1)
lines(svysmooth(I(H_LIEU_agr == "Études") ~ ANAISR, bandwidth=bw,
                subset(svyhist, H_NREL_CORR == 1 & SEXER == "H")),
      lty=2, lwd=2)
lines(svysmooth(I(H_LIEU_agr == "Études") ~ ANAISR, bandwidth=bw,
                subset(svyhist, H_NREL_CORR == 1 & SEXER == "F")),
      lty=1, lwd=2)


#relations à l'enquête
plot(NULL, main="Relations en cours à l'enquête", yaxt="n",
     xlim=c(1948, 1988), xaxs="i", ylim=c(0, .8), lwd=0,
     ylab="",
     xlab="Année de naissance")
axis(2, seq(0, 1, by=.1), seq(0, 100,  by=10))
abline(h=seq(0, 1, by=.1), col="light grey", lty="dotted")
#lignes
lines(svysmooth(temps_etude ~ ANAISR, bandwidth=bw,
                subset(svyrep, SEXER == "H")),
      lty=2)
lines(svysmooth(temps_etude ~ ANAISR, bandwidth=bw,
                subset(svyrep, SEXER == "F")),
      lty=1)
lines(svysmooth(I(H_LIEU_agr_C == "Études") ~ ANAISR, bandwidth=bw,
                subset(svyrep, SEXER == "H")),
      lty=2, lwd=2)
lines(svysmooth(I(H_LIEU_agr_C == "Études") ~ ANAISR, bandwidth=bw,
                subset(svyrep, SEXER == "F")),
      lty=1, lwd=2)

par(mar=c(0, 1, 0, 1))
plot.new()
legend("right", ncol=2,
       title="Mise en couple avant la fin des études :",
       c("Hommes", "Femmes"),
       lwd=1, lty=2:1, bty="n")
plot.new()
legend("left", ncol=2,
       title="Rencontre dans le cadre des études :",
       c("Hommes", "Femmes"),
       lwd=2, lty=2:1, bty="n")
par(opar)


# Figure 2
# Homogamie de diplôme et d’origine sociale selon le lieu de rencontre
homodip <- prop.table(svytable(~ H_LIEU_agr_C + C_homodip, svyrep), 1)[,"Homogame"]*100
homocs6p <- prop.table(svytable(~ H_LIEU_agr_C + C_homocs6p, svyrep), 1)[,"Homogame"]*100

homodip1 <- prop.table(svytable(~ H_LIEU_agr_C + C_homodip, subset(svyrep, ANAISR < 1968)), 1)[,"Homogame"]*100
homocs6p1 <- prop.table(svytable(~ H_LIEU_agr_C + C_homocs6p, subset(svyrep, ANAISR < 1968)), 1)[,"Homogame"]*100
homodip2 <- prop.table(svytable(~ H_LIEU_agr_C + C_homodip, subset(svyrep, ANAISR >= 1968)), 1)[,"Homogame"]*100
homocs6p2 <- prop.table(svytable(~ H_LIEU_agr_C + C_homocs6p, subset(svyrep, ANAISR >= 1968)), 1)[,"Homogame"]*100

plot(homodip, homocs6p, asp=1, pch=4,
     xlim=range(c(homodip1, homodip2)), ylim=range(c(homocs6p1, homocs6p2)),
     xlab="Homogamie de diplôme (en % des couples)",
     ylab="Homogamie d'origine sociale (en % des couples)")
text(homodip, homocs6p, labels=names(homodip), adj=1.1)
sig.cs <- c("Famille", "Lieux publics", "Travail")
sig.dip <- c("Lieux publics")
homodip.sig1 <- homodip[union(sig.dip, sig.cs)]
homodip.sig2 <- homodip[union(sig.dip, sig.cs)]
homodip.sig1[sig.dip] <- homodip1[sig.dip]
homodip.sig2[sig.dip] <- homodip2[sig.dip]
homocs6p.sig1 <- homocs6p[union(sig.dip, sig.cs)]
homocs6p.sig2 <- homocs6p[union(sig.dip, sig.cs)]
homocs6p.sig1[sig.cs] <- homocs6p1[sig.cs]
homocs6p.sig2[sig.cs] <- homocs6p2[sig.cs]
arrows(homodip.sig1, homocs6p.sig1, homodip.sig2, homocs6p.sig2, angle=30, length=.15)
text(47.5, 41.75, "Cohorte de naissance :", pos=3, cex=.8)
text(45, 41, "1948-67", pos=3, cex=.8)
text(50, 41, "1968-88", pos=3, cex=.8)
arrows(45, 41, 50, 41, angle=30, length=.15)
points(47.5, 41, pch=4)
text(47.5, 41, "Ensemble", pos=1, cex=.8)
rect(43, 39.5, 100, 100, pch=4)


# Figure 3
# Distance et écart genré en fonction de la cohorte de naissance et du diplôme
svymean(~I(abs(ecart_act)), subset(svyrep.symF, ANAISR<1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Homo" & ANAISR<1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Hyper" & ANAISR<1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Hypo" & ANAISR<1968), na.rm=TRUE)

svymean(~I(abs(ecart_act)), subset(svyrep.symF, ANAISR>=1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Homo" & ANAISR>=1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Hyper" & ANAISR>=1968), na.rm=TRUE)
svymean(~I(abs(ecart_act)), subset(svyrep.symF, C_hyperdip=="Hypo" & ANAISR>=1968), na.rm=TRUE)


svymean(~I(-ecart_act), subset(svyrep.symF.act, ANAISR<1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Homo" & ANAISR<1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Hyper" & ANAISR<1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Hypo" & ANAISR<1968), na.rm=TRUE)

svymean(~I(-ecart_act), subset(svyrep.symF, ANAISR>=1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Homo" & ANAISR>=1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Hyper" & ANAISR>=1968), na.rm=TRUE)
svymean(~I(-ecart_act), subset(svyrep.symF, C_hyperdip=="Hypo" & ANAISR>=1968), na.rm=TRUE)


# Figure 4: regression
dat <- subset(svyrep.symF, IndCOU)
dat$variables$var_ecart <- with(dat$variables, ecart_act - ecart_debract)
dat$variables$hyper_debract <- recode_factor(sign(dat$variables$ecart_debract), `-1`="Hyper", `0`="Homo", `1`="Hypo")
dat$variables$ecart_act <- -dat$variables$ecart_act
dat$variables$ecart_debract <- -scale(dat$variables$ecart_debract, scale=FALSE)
dat$variables$ecart_debract_abs <- scale(abs(dat$variables$ecart_debract), scale=FALSE)
dat$variables$dist_dip <- scale(with(dat$variables, abs(as.integer(C_dipC)-as.integer(M_dip))), scale=FALSE)
dat$variables$ecart_dip <- scale(with(dat$variables, as.integer(C_dipC)-as.integer(M_dip)), scale=FALSE)
dat$variables$C_act <- dat$variables$M_ACT %in% c(1, 2, 3, 5)
dat$variables$C_actC <- dat$variables$C_ACTC %in% c(1, 2, 3, 5)
dat$variables$C_duree10 <- cut(dat$variables$C_duree, c(0, 5, 15, 25, 35, 100), right=FALSE)
dat$variables$H_NBENF2_C <- recode(dat$variables$H_NBENF_C, `1`="1 enfant", `2`="2 enfants", .default="3 enfants et +", .missing="Aucun")
dat$variables$H_AENF1_C[is.na(dat$variables$H_AENF1_C)] <- 2015
dat$variables$H_AENF1_C[dat$variables$H_AENF1_C %in% c(9998, 9999)] <- NA
dat$variables$H_duree_enf1_C <- 2015 - dat$variables$H_AENF1_C
dat$variables$H_duree_enf1_C10 <- cut(dat$variables$H_duree_enf1_C, c(0, 1, 10, 20, 100), right=FALSE)
dat$variables$H_duree_enf1_C10 <- relevel(dat$variables$H_duree_enf1_C10, "[1,10)")

dat2 <- subset(dat,
               complete.cases(dat$variables[c("C_duree", "C_hyperdip", "H_NREL_C", "ANAISR")]))
dat <- subset(dat,
              complete.cases(dat$variables[c("var_ecart", "C_duree", "C_hyperdip", "H_NREL_C", "ANAISR")]))

m1.diff <- svyglm(diff_act ~ C_duree10 + C_hyperdip + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948) + H_NBENF2_C, dat)
m1bis.diff <- svyglm(diff_act ~ C_duree10 + C_hyperdip*C_duree10 + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948) + H_NBENF2_C, dat)
m2.diff <- update(m1.diff, ~ . + C_duree10*ecart_debract_abs)

m1.ecart <- svyglm(ecart_act ~ C_duree10 + C_hyperdip + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948) + H_NBENF2_C, dat)
m1bis.ecart <- svyglm(ecart_act ~ C_duree10+ C_hyperdip*C_duree10 + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948) + H_NBENF2_C, dat)
m2.ecart <- update(m1.ecart, ~ . + C_duree10*ecart_debract)

library(stargazer)
options(OutDec=".")
table <- stargazer(m1.diff, m2.diff, m1.ecart, m2.ecart,
                   type="text", out.header=TRUE,
                   intercept.bottom=FALSE, intercept.top=TRUE, report="vcs", notes="", notes.append=FALSE,
                   ci=TRUE, ci.separator=" ; ",
                   keep.stat=c("rsq", "aic"), digits=2, decimal.mark=",", digit.separate=0,
                   dep.var.caption="", dep.var.labels.include=FALSE,
                   omit=c("M_dip", "C_dip"), omit.labels=c("Diplômes des conjoints", ""), omit.yes.no=c("×", ""),
                   column.separate=c(2, 2), column.labels=c("Distance (hétérogamie)", "Écart genré (hypergamie)"),
                   covariate.labels=c("Constante", "5 à 14 ans", "15 à 24 ans", "25 à 34 ans", "35 ans et plus",
                                      "Homme plus diplômé", "Femme plus diplômée",
                                      "Union ultérieure pour la femme", "Union ultérieure pour l'homme",
                                      "Femme inactive à l'enquête", "Homme inactif à l'enquête",
                                      "Année de naissance du répondant (0 pour 1948)",
                                      "1 enfant", "2 enfants", "3 enfants et plus",
                                      "Distance en début de relation (centrée)",
                                      "Distance initiale × 5 à 14 ans", "Distance initiale × 15 à 24 ans",
                                      "Distance initiale × 25 à 34 ans", "Distance initiale × 35 ans et plus",
                                      "Écart genré en début de relation (centré)",
                                      "Écart initial × 5 à 14 ans", "Écart initial × 15 à 24 ans",
                                      "Écart initial × 25 à 34 ans", "Écart initial × 35 ans et plus"))


sapply(list(m1.diff, m1bis.diff, m2.diff,
            m1.ecart, m1bis.ecart, m2.ecart),
       function(m) cor(fitted(m), m$y)^2)

dat2$variables$sel <- !is.na(dat2$variables$ecart_debract)

library(sampleSelection)
mod <- selection(selection=sel ~ C_agedeb + H_agedeb_C + C_duree10 + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948),
                 outcome=diff_act ~ C_duree10 + C_duree10*ecart_debract_abs + C_hyperdip + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948),
                 data=dat2$variables, method="2step")
mod <- selection(selection=sel ~ C_agedeb + H_agedeb_C + C_duree10 + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948),
                 outcome=ecart_act ~ C_duree10 + C_duree10*ecart_debract + C_hyperdip + H_premcoup_C + H_premcoupC_C + C_act + C_actC + I(ANAISR-1948),
                 data=dat2$variables, method="2step")
summary(mod)
