library(logmult)

models.summary <- function(models) {
  stopifnot(all(sapply(models, function(model) all(model$data == models[[1]]$data, na.rm=TRUE))))
  
  df <- sapply(models, function(model) if(!is.null(model)) model$df.residual else NA)
  deviances <- sapply(models, function(model) if(!is.null(model)) round(model$deviance) else NA)
  errors <- sapply(models, function(model) {
    if(!is.null(model)) round(sum(abs(fitted(model)-model$data), na.rm=TRUE)/sum(abs(fitted(model)), na.rm=TRUE)*100/2, digits=2)
    else NA })
  bics <- sapply(models, function(model) if(!is.null(model)) model$dev - log(sum(model$data, na.rm=TRUE)) * model$df.residual)
  aics <- sapply(models, function(model) if(!is.null(model)) model$dev - 2 * model$df.residual)
  
  for(i in 1:length(models)) if(!isTRUE(models[[i]]$converged)) warning("Model ", names(models)[i], " did not converge!")
  data.frame(row.names=names(models), D.F.=df, Deviance=deviances, "Δ (%)"=errors, BIC=round(bics), AIC=round(aics), check.names=FALSE)
}

par(mfrow=c(1, 2))
levels(svyrep.symH$variables$H_LIEU_agr_C) <- c("Internet", "Public places", "Leisure", "School", "Work", "Friends", "Family")
dat1 <- subset(svyrep.symH, ANAISR < 1968)
dat2 <- subset(svyrep.symH, ANAISR >= 1968)

tab1 <- svytable(~ M_dip + C_dipC + H_LIEU_agr_C, dat1,
                 Ntotal=sum(with(dat1$variables, table(M_dip, C_dipC, H_LIEU_agr_C))))
tab2 <- svytable(~ M_dip + C_dipC + H_LIEU_agr_C, dat2,
                 Ntotal=sum(with(dat2$variables, table(M_dip, C_dipC, H_LIEU_agr_C))))
i1 <- glm(Freq ~ H_LIEU_agr_C*(M_dip + C_dipC), tab1, family=poisson)
i2 <- glm(Freq ~ H_LIEU_agr_C*(M_dip + C_dipC), tab2, family=poisson)
s1 <- glm(Freq ~ H_LIEU_agr_C*(M_dip + C_dipC) + M_dip*C_dipC, tab1, family=poisson)
s2 <- glm(Freq ~ H_LIEU_agr_C*(M_dip + C_dipC) + M_dip*C_dipC, tab2, family=poisson)
u1 <- unidiff(tab1)
u2 <- unidiff(tab2)

models.summary(list(i1, s1, u1))
models.summary(list(i2, s2, u2))

plot(u1, what="phi", ylim=c(0, 4), xlab="", main="Educational Homogamy")
plot(u2, what="phi", add=T, pch=2)
abline(h=c(1, 2, 5, 10, 20), col="grey", lty="dotted")
abline(h=1, col="dark grey")
legend("topleft", c("1948-1967 Cohorts", "1968-1988 Cohorts"), pch=1:2)

tab1 <- svytable(~ F_CS6P + C_CS6PC + H_LIEU_agr_C, dat1,
                 Ntotal=sum(with(dat1$variables, table(F_CS6P, C_CS6PC, H_LIEU_agr_C))))
tab2 <- svytable(~ F_CS6P + C_CS6PC + H_LIEU_agr_C, dat2,
                 Ntotal=sum(with(dat2$variables, table(F_CS6P, C_CS6PC, H_LIEU_agr_C))))
i1 <- glm(Freq ~ H_LIEU_agr_C*(F_CS6P + C_CS6PC), tab1, family=poisson)
i2 <- glm(Freq ~ H_LIEU_agr_C*(F_CS6P + C_CS6PC), tab2, family=poisson)
s1 <- glm(Freq ~ H_LIEU_agr_C*(F_CS6P + C_CS6PC) + F_CS6P*C_CS6PC, tab1, family=poisson)
s2 <- glm(Freq ~ H_LIEU_agr_C*(F_CS6P + C_CS6PC) + F_CS6P*C_CS6PC, tab2, family=poisson)
u1 <- unidiff(tab1)
u2 <- unidiff(tab2)

models.summary(list(i1, s1, u1))
models.summary(list(i2, s2, u2))

plot(u1, what="phi", ylim=c(0, 4), xlab="", main="Social Origin Homogamy")
plot(u2, what="phi", add=T, pch=2)
abline(h=c(1, 2, 5, 10, 20), col="grey", lty="dotted")
abline(h=1, col="dark grey")
legend("topleft", c("1948-1967 Cohorts", "1968-1988 Cohorts"), pch=1:2)